==> rucy-0.0.0.tar.gz: rucy-0.0.0/test/test_FilterMap.rb <==
#!/usr/local/bin/ruby
# $Id: test_FilterMap.rb,v 1.1.1.1 2004/04/04 15:22:50 toki Exp $

require 'rubyunit'
require 'wpm'
require 'rucy/document'

module TestRucy
  class TestFilterMap < RUNIT::TestCase
    def setup
      # for WPM::Driver class
      @driver_call = 0
      @redirect_call = 0
      @redirect_last_page_name = nil
      @redirect_last_query_params = nil

      # for Rucy::DocumentFactory class
      @factory = Rucy::DocumentFactory.new
      erb = Object.new
      def erb.filter_name
	'eRuby'
      end
      def erb.filter_args
	[ [ 'safe level', :number, 1 ] ]
      end
      @factory.add_filter(erb)
      ssi = Object.new
      def ssi.filter_name
	'SSI'
      end
      def ssi.filter_args
	[ [ 'SSI commands', :checkset,
	    [ [ 'config',   true ],
	      [ 'include',  true ],
	      [ 'echo',     true ],
	      [ 'fsize',    true ],
	      [ 'flastmod', true ],
	      [ 'exec',     true ]
	    ]
	  ]
	]
      end
      @factory.add_filter(ssi)
      @filter_args_call = 0
      @filter_names_call = 0

      # for Rucy::Control class
      @modified_count_call = 0
      @set_modified_count_call = 0
      @set_modified_count_value = nil
      @filter_list = [
	{ 'filter' => 'eRuby',
	  'arguments' => [ 1 ],
	  'attach_path' => '/eRuby',
	  'attach_mask' => %r/\.rhtml?/,
	  'virtual_host' => nil,
	  'comment' => 'test of eRuby'
	},
	{ 'filter' => 'SSI',
	  'arguments' => [
	    { 'config'   => true,
	      'include'  => true,
	      'echo'     => true,
	      'fsize'    => true,
	      'flastmod' => true,
	      'exec'     => false
	    }
	  ],
	  'attach_path' => '/~alice',
	  'attach_mask' => %r/\.shtml?/,
	  'virtual_host' => 'foo',
	  'comment' => 'test of SSI'
	}
      ]
      @filters_call = 0
      @set_filters_call = 0

      # setup WPM::PageContext class
      loader = WPM::Loader.new('../control/FilterMap/FilterMap.rb')
      @FilterMap = loader.const_get('FilterMap').new(self, :control => self, :factory => self)
      assert((@FilterMap.is_a? WPM::PageContext))
      @FilterMap.init_context
      assert_equal(1, @filters_call)
    end

    def driver
      @driver_call += 1
      self
    end

    def redirect(page_name, query_params=nil)
      @redirect_call += 1
      @redirect_last_page_name = page_name
      @redirect_last_query_params = query_params
      nil
    end

    def filter_args(filter_name)
      @filter_args_call += 1
      @factory.filter_args(filter_name)
    end

    def filter_names
      @filter_names_call += 1
      @factory.filter_names
    end

    def modified_count
      @modified_count_call += 1
      0
    end

    def modified_count=(modified_count)
      @set_modified_count_call += 1
      @set_modified_count_value = modified_count
    end

    def filters
      @filters_call += 1
      filter_list = @filter_list.dup
      def filter_list.setup(parent)
	@parent = parent
	self
      end
      def filter_list.modified_count
	@parent.modified_count
      end
      def filter_list.modified_count=(modified_count)
	@parent.modified_count = modified_count
      end
      filter_list.setup(self)
    end

    def set_filters(filter_list)
      @set_filters_call += 1
      @filter_list = filter_list
      nil
    end

    def test_modified_count
      assert_equal(0, @FilterMap.modified_count)
      assert_equal(1, @modified_count_call)
      assert_equal(1, @FilterMap.modified_count = 1)
      assert_equal(1, @set_modified_count_call)
      assert_equal(1, @set_modified_count_value)
    end

    def test_document_list
      filter_list = @FilterMap.document_list
      assert(! filter_list.empty?)
      assert_equal(2, filter_list.length)
      assert_equal('eRuby', filter_list[0]['filter'])
      assert_equal(1, filter_list[0]['arguments'].length)
      assert_equal(1, filter_list[0]['arguments'][0])
      assert_equal('/eRuby', filter_list[0]['attach_path'])
      assert_equal(%r/\.rhtml?/, filter_list[0]['attach_mask'])
      assert_nil(filter_list[0]['virtual_host'])
      assert_equal('test of eRuby', filter_list[0]['comment'])
      assert_equal('SSI', filter_list[1]['filter'])
      assert_equal(1, filter_list[1]['arguments'].length)
      assert_equal({ 'config'   => true,
		     'include'  => true,
		     'echo'     => true,
		     'fsize'    => true,
		     'flastmod' => true,
		     'exec'     => false
		   }, filter_list[1]['arguments'][0])
      assert_equal('/~alice', filter_list[1]['attach_path'])
      assert_equal(%r/\.shtml?/, filter_list[1]['attach_mask'])
      assert_equal('foo', filter_list[1]['virtual_host'])
      assert_equal('test of SSI', filter_list[1]['comment'])
    end

    def test_document_factory
      assert_equal([ [ 'SSI commands', :checkset,
		       [ [ 'config',   true ],
			 [ 'include',  true ],
			 [ 'echo',     true ],
			 [ 'fsize',    true ],
			 [ 'flastmod', true ],
			 [ 'exec',     true ]
		       ]
		     ]
		   ], @FilterMap.doc_args('SSI'))
      assert_equal(1, @filter_args_call)
      assert_equal([ 'SSI', 'eRuby' ], @FilterMap.doc_names)
      assert_equal(1, @filter_names_call)
    end

    def test_document_attributes
      assert_equal('filter', @FilterMap.doc_tag)
      assert_equal('filter', @FilterMap.doc_label)
      assert_equal('attach_path', @FilterMap.path_tag)
      assert_equal('attach path', @FilterMap.path_label)
      assert_equal('attach_mask', @FilterMap.mask_tag)
      assert_equal('attach mask', @FilterMap.mask_label)
    end

    def test_write_document_list
      @FilterMap.write_document_list
      assert_equal(1, @set_filters_call)
    end

    def test_setup_document
      @FilterMap.setup_document('eRuby', 2)
      assert_equal(1, @driver_call)
      assert_equal(1, @redirect_call)
      assert_equal('SetupFilter', @redirect_last_page_name)
      assert_equal({ 'filter' => 'eRuby',
		     'pos'    => '2'
		   }, @redirect_last_query_params)
    end
  end
end

==> rucy-0.2.0.tar.gz: rucy-0.2.0/test/test_FilterMap.rb <==
#!/usr/local/bin/ruby
# $Id: test_FilterMap.rb,v 1.2 2004/10/13 15:21:33 toki Exp $

require 'rubyunit'
require 'wpm'
require 'rucy/document'

module TestRucy
  class TestFilterMap < RUNIT::TestCase
    def setup
      # for WPM::Driver class
      @driver_call = 0
      @redirect_call = 0
      @redirect_last_page_name = nil
      @redirect_last_query_params = nil

      # for Rucy::DocumentFactory class
      @factory = Rucy::DocumentFactory.new
      erb = Object.new
      def erb.filter_name
	'eRuby'
      end
      def erb.filter_args
	[ [ 'safe level', :number, 1 ] ]
      end
      @factory.add_filter(erb)
      ssi = Object.new
      def ssi.filter_name
	'SSI'
      end
      def ssi.filter_args
	[ [ 'SSI commands', :checkset,
	    [ [ 'config',   true ],
	      [ 'include',  true ],
	      [ 'echo',     true ],
	      [ 'fsize',    true ],
	      [ 'flastmod', true ],
	      [ 'exec',     true ]
	    ]
	  ]
	]
      end
      @factory.add_filter(ssi)
      @filter_args_call = 0
      @filter_names_call = 0

      # for Rucy::Control class
      @modified_count_call = 0
      @set_modified_count_call = 0
      @set_modified_count_value = nil
      @filter_list = [
	{ 'filter' => 'eRuby',
	  'arguments' => [ 1 ],
	  'attach_path' => '/eRuby',
	  'attach_mask' => %r/\.rhtml?/,
	  'virtual_host' => nil,
	  'comment' => 'test of eRuby'
	},
	{ 'filter' => 'SSI',
	  'arguments' => [
	    { 'config'   => true,
	      'include'  => true,
	      'echo'     => true,
	      'fsize'    => true,
	      'flastmod' => true,
	      'exec'     => false
	    }
	  ],
	  'attach_path' => '/~alice',
	  'attach_mask' => %r/\.shtml?/,
	  'virtual_host' => 'foo',
	  'comment' => 'test of SSI'
	}
      ]
      @filters_call = 0
      @set_filters_call = 0

      # setup WPM::PageContext class
      loader = WPM::Loader.new('../control/FilterMap/FilterMap.rb')
      @FilterMap = loader.const_get('FilterMap').new(self, { :control => self, :factory => self })
      assert((@FilterMap.is_a? WPM::PageContext))
      @FilterMap.init_context
      assert_equal(1, @filters_call)
    end

    def driver
      @driver_call += 1
      self
    end

    def redirect(page_name, query_params=nil)
      @redirect_call += 1
      @redirect_last_page_name = page_name
      @redirect_last_query_params = query_params
      nil
    end

    def filter_args(filter_name)
      @filter_args_call += 1
      @factory.filter_args(filter_name)
    end

    def filter_names
      @filter_names_call += 1
      @factory.filter_names
    end

    def modified_count
      @modified_count_call += 1
      0
    end

    def modified_count=(modified_count)
      @set_modified_count_call += 1
      @set_modified_count_value = modified_count
    end

    def filters
      @filters_call += 1
      filter_list = @filter_list.dup
      def filter_list.setup(parent)
	@parent = parent
	self
      end
      def filter_list.modified_count
	@parent.modified_count
      end
      def filter_list.modified_count=(modified_count)
	@parent.modified_count = modified_count
      end
      filter_list.setup(self)
    end

    def set_filters(filter_list)
      @set_filters_call += 1
      @filter_list = filter_list
      nil
    end

    def test_modified_count
      assert_equal(0, @FilterMap.modified_count)
      assert_equal(1, @modified_count_call)
      assert_equal(1, @FilterMap.modified_count = 1)
      assert_equal(1, @set_modified_count_call)
      assert_equal(1, @set_modified_count_value)
    end

    def test_document_list
      filter_list = @FilterMap.document_list
      assert(! filter_list.empty?)
      assert_equal(2, filter_list.length)
      assert_equal('eRuby', filter_list[0]['filter'])
      assert_equal(1, filter_list[0]['arguments'].length)
      assert_equal(1, filter_list[0]['arguments'][0])
      assert_equal('/eRuby', filter_list[0]['attach_path'])
      assert_equal(%r/\.rhtml?/, filter_list[0]['attach_mask'])
      assert_nil(filter_list[0]['virtual_host'])
      assert_equal('test of eRuby', filter_list[0]['comment'])
      assert_equal('SSI', filter_list[1]['filter'])
      assert_equal(1, filter_list[1]['arguments'].length)
      assert_equal({ 'config'   => true,
		     'include'  => true,
		     'echo'     => true,
		     'fsize'    => true,
		     'flastmod' => true,
		     'exec'     => false
		   }, filter_list[1]['arguments'][0])
      assert_equal('/~alice', filter_list[1]['attach_path'])
      assert_equal(%r/\.shtml?/, filter_list[1]['attach_mask'])
      assert_equal('foo', filter_list[1]['virtual_host'])
      assert_equal('test of SSI', filter_list[1]['comment'])
    end

    def test_document_factory
      assert_equal([ [ 'SSI commands', :checkset,
		       [ [ 'config',   true ],
			 [ 'include',  true ],
			 [ 'echo',     true ],
			 [ 'fsize',    true ],
			 [ 'flastmod', true ],
			 [ 'exec',     true ]
		       ]
		     ]
		   ], @FilterMap.doc_args('SSI'))
      assert_equal(1, @filter_args_call)
      assert_equal([ 'SSI', 'eRuby' ], @FilterMap.doc_names)
      assert_equal(1, @filter_names_call)
    end

    def test_document_attributes
      assert_equal('filter', @FilterMap.doc_tag)
      assert_equal('filter', @FilterMap.doc_label)
      assert_equal('attach_path', @FilterMap.path_tag)
      assert_equal('attach path', @FilterMap.path_label)
      assert_equal('attach_mask', @FilterMap.mask_tag)
      assert_equal('attach mask', @FilterMap.mask_label)
    end

    def test_write_document_list
      @FilterMap.write_document_list
      assert_equal(1, @set_filters_call)
    end

    def test_setup_document
      @FilterMap.setup_document('eRuby', 2)
      assert_equal(1, @driver_call)
      assert_equal(1, @redirect_call)
      assert_equal('SetupFilter', @redirect_last_page_name)
      assert_equal({ 'filter' => 'eRuby',
		     'pos'    => '2'
		   }, @redirect_last_query_params)
    end
  end
end
